Learn R Programming

wikisourcer (version 0.1.5)

gracefully_fail: Fail gracefully if Wikisource resources are not available

Description

The function allows to fail gracefully with an informative message if the Wikisource resource is not available (and not give a check warning nor error).

Usage

gracefully_fail(remote_url)

Arguments

remote_url

A remote URL.

Details

See full discussion to be compliante with the CRAN policy <https://community.rstudio.com/t/internet-resources-should-fail-gracefully/49199>